@@ -1,4 +1,5 @@
-require 'capybara'
+# frozen_string_literal: true
+require 'capybara/dsl'
 require 'capybara/rspec/matchers'
 
 World(Capybara::DSL)
