@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 module Capybara
   module Node
 
@@ -16,13 +17,13 @@ module Capybara
     #
     #     session = Capybara::Session.new(:rack_test, my_app)
     #     session.visit('/')
-    #     session.fill_in('Foo', :with => 'Bar')    # from Capybara::Node::Actions
+    #     session.fill_in('Foo', with: 'Bar')    # from Capybara::Node::Actions
     #     bar = session.find('#bar')                # from Capybara::Node::Finders
-    #     bar.select('Baz', :from => 'Quox')        # from Capybara::Node::Actions
+    #     bar.select('Baz', from: 'Quox')        # from Capybara::Node::Actions
     #     session.has_css?('#foobar')               # from Capybara::Node::Matchers
     #
     class Base
-      attr_reader :session, :base, :parent
+      attr_reader :session, :base, :query_scope
 
       include Capybara::Node::Finders
       include Capybara::Node::Actions
@@ -107,6 +108,12 @@ module Capybara
         base.find_xpath(xpath)
       end
 
+      # @deprecated Use query_scope instead
+      def parent
+        warn "DEPRECATED: #parent is deprecated in favor of #query_scope - Note: #parent was not the elements parent in the document so it's most likely not what you wanted anyway"
+        query_scope
+      end
+
     protected
 
       def catch_error?(error, errors = nil)
