@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 module Capybara
   module Node
 
@@ -9,7 +10,7 @@ module Capybara
     #     session = Capybara::Session.new(:rack_test, my_app)
     #
     #     bar = session.find('#bar')              # from Capybara::Node::Finders
-    #     bar.select('Baz', :from => 'Quox')      # from Capybara::Node::Actions
+    #     bar.select('Baz', from: 'Quox')      # from Capybara::Node::Actions
     #
     # {Capybara::Node::Element} also has access to HTML attributes and other properties of the
     # element:
@@ -22,9 +23,9 @@ module Capybara
     #
     class Element < Base
 
-      def initialize(session, base, parent, query)
+      def initialize(session, base, query_scope, query)
         super(session, base)
-        @parent = parent
+        @query_scope = query_scope
         @query = query
       end
 
@@ -281,6 +282,26 @@ module Capybara
         synchronize { base.disabled? }
       end
 
+      ##
+      #
+      # Whether or not the element is readonly.
+      #
+      # @return [Boolean]     Whether the element is readonly
+      #
+      def readonly?
+        synchronize { base.readonly? }
+      end
+
+      ##
+      #
+      # Whether or not the element supports multiple results.
+      #
+      # @return [Boolean]     Whether the element supports multiple results.
+      #
+      def multiple?
+        synchronize { base.multiple? }
+      end
+
       ##
       #
       # An XPath expression describing where on the page the element can be found
@@ -319,7 +340,7 @@ module Capybara
       def reload
         if @allow_reload
           begin
-            reloaded = parent.reload.first(@query.name, @query.locator, @query.options)
+            reloaded = query_scope.reload.first(@query.name, @query.locator, @query.options)
             @base = reloaded.base if reloaded
           rescue => e
             raise e unless catch_error?(e)
