@@ -1,3 +1,6 @@
+# frozen_string_literal: true
+require 'addressable/uri'
+
 module Capybara
   # @api private
   module Queries
@@ -15,16 +18,16 @@ module Capybara
           session.current_url
         else
           if options[:only_path]
-            URI.parse(session.current_url).path
+            ::Addressable::URI.parse(session.current_url).path
           else
-            URI.parse(session.current_url).request_uri
+            ::Addressable::URI.parse(session.current_url).request_uri
           end
         end
 
         if @expected_path.is_a? Regexp
           @actual_path.match(@expected_path)
         else
-          @expected_path == @actual_path
+          ::Addressable::URI.parse(@expected_path) == Addressable::URI.parse(@actual_path)
         end
       end
 
