@@ -1,4 +1,4 @@
-require 'capybara'
+# frozen_string_literal: true
 require 'capybara/dsl'
 
 Capybara.app = Rack::Builder.new do
@@ -12,9 +12,9 @@ Capybara.app = Rack::Builder.new do
   end
 end.to_app
 
-Capybara.save_and_open_page_path = Rails.root.join('tmp/capybara')
+Capybara.save_path = Rails.root.join('tmp/capybara')
 
 # Override default rack_test driver to respect data-method attributes.
 Capybara.register_driver :rack_test do |app|
-  Capybara::RackTest::Driver.new(app, :respect_data_method => true)
+  Capybara::RackTest::Driver.new(app, respect_data_method: true)
 end
