@@ -1,4 +1,6 @@
+# frozen_string_literal: true
 require 'capybara/session/matchers'
+require 'addressable/uri'
 
 module Capybara
 
@@ -19,7 +21,7 @@ module Capybara
   # +current_path, and so on. It also delegate a number of methods to a Capybara::Document, representing
   # the current HTML document. This allows interaction:
   #
-  #     session.fill_in('q', :with => 'Capybara')
+  #     session.fill_in('q', with: 'Capybara')
   #     session.click_button('Search')
   #     expect(session).to have_content('Capybara')
   #
@@ -106,9 +108,9 @@ module Capybara
     def reset!
       if @touched
         driver.reset!
-        assert_no_selector :xpath, "/html/body/*" if driver.browser_initialized?
         @touched = false
       end
+      @server.wait_for_pending_requests if @server
       raise_server_error!
     end
     alias_method :cleanup!, :reset!
@@ -119,7 +121,15 @@ module Capybara
     # Raise errors encountered in the server
     #
     def raise_server_error!
-      raise @server.error if Capybara.raise_server_errors and @server and @server.error
+      if Capybara.raise_server_errors and @server and @server.error
+        # Force an explanation for the error being raised as the exception cause
+        begin
+          raise CapybaraError, "Your application server raised an error - It has been raised in your test code because Capybara.raise_server_errors == true"
+        rescue CapybaraError
+          #needed to get the cause set correctly in JRuby -- otherwise we could just do raise @server.error
+          raise @server.error, @server.error.message, @server.error.backtrace
+        end
+      end
     ensure
       @server.reset_error! if @server
     end
@@ -159,7 +169,11 @@ module Capybara
     # @return [String] Path of the current page, without any domain information
     #
     def current_path
-      path = URI.parse(current_url).path
+      # Addressable parsing is more lenient than URI
+      uri = Addressable::URI.parse(current_url)
+      # Addressable doesn't support opaque URIs - we want nil here
+      return nil if uri.scheme == "about"
+      path = uri.path
       path if path and not path.empty?
     end
 
@@ -204,32 +218,32 @@ module Capybara
     #
     # Will actually navigate to `http://google.com:4567/test`.
     #
-    # @param [#to_s] url     The URL to navigate to. The parameter will be cast to a String.
+    # @param [#to_s] visit_uri     The URL to navigate to. The parameter will be cast to a String.
     #
-    def visit(url)
+    def visit(visit_uri)
       raise_server_error!
-
-      url = url.to_s
       @touched = true
 
-      url_relative = URI.parse(url).scheme.nil?
+      visit_uri = URI.parse(visit_uri.to_s)
 
-      if url_relative && Capybara.app_host
-        url = Capybara.app_host + url
-        url_relative = false
+      uri_base = if @server
+        visit_uri.port = @server.port if Capybara.always_include_port && (visit_uri.port == visit_uri.default_port)
+        URI.parse(Capybara.app_host || "http://#{@server.host}:#{@server.port}")
+      else
+        Capybara.app_host && URI.parse(Capybara.app_host)
       end
 
-      if @server
-        url = "http://#{@server.host}:#{@server.port}" + url if url_relative
-
-        if Capybara.always_include_port
-          uri = URI.parse(url)
-          uri.port = @server.port if uri.port == uri.default_port
-          url = uri.to_s
-        end
+      # TODO - this is only for compatability with previous 2.x behavior that concatenated
+      # Capybara.app_host and a "relative" path - Consider removing in 3.0
+      # @abotalov brought up a good point about this behavior potentially being useful to people
+      # deploying to a subdirectory and/or single page apps where only the url fragment changes
+      if visit_uri.scheme.nil? && uri_base
+        visit_uri.path = uri_base.path + visit_uri.path
       end
 
-      driver.visit(url)
+      visit_uri = uri_base.merge(visit_uri) unless uri_base.nil?
+
+      driver.visit(visit_uri.to_s)
     end
 
     ##
@@ -256,7 +270,7 @@ module Capybara
     # to the given element.
     #
     #     within(:xpath, '//div[@id="delivery-address"]') do
-    #       fill_in('Street', :with => '12 Main Street')
+    #       fill_in('Street', with: '12 Main Street')
     #     end
     #
     # Just as with `find`, if multiple elements match the selector given to
@@ -267,13 +281,13 @@ module Capybara
     # assumed to be of the type set in Capybara.default_selector.
     #
     #     within('div#delivery-address') do
-    #       fill_in('Street', :with => '12 Main Street')
+    #       fill_in('Street', with: '12 Main Street')
     #     end
     #
     # Note that a lot of uses of `within` can be replaced more succinctly with
     # chaining:
     #
-    #     find('div#delivery-address').fill_in('Street', :with => '12 Main Street')
+    #     find('div#delivery-address').fill_in('Street', with: '12 Main Street')
     #
     # @overload within(*find_args)
     #   @param (see Capybara::Node::Finders#all)
@@ -319,18 +333,47 @@ module Capybara
 
     ##
     #
-    # Execute the given block within the given iframe using given frame name or index.
-    # May be supported by not all drivers. Drivers that support it, may provide additional options.
+    # Execute the given block within the given iframe using given frame, frame name/id or index.
+    # May not be supported by all drivers.
     #
+    # @overload within_frame(element)
+    #   @param [Capybara::Node::Element]  frame element
+    # @overload within_frame(name)
+    #   @param [String] name           name/id of a frame
     # @overload within_frame(index)
     #   @param [Integer] index         index of a frame
-    # @overload within_frame(name)
-    #   @param [String] name           name of a frame
     #
-    def within_frame(frame_handle)
+    def within_frame(locator)
       scopes.push(nil)
-      driver.within_frame(frame_handle) do
-        yield
+
+      #support older driver frame api for now
+      frame = case locator
+      when Capybara::Node::Element
+        locator
+      when String
+        find(:frame, locator)
+      when Integer
+        all(:frame, minimum: locator+1)[locator]
+      else
+        raise ArgumentError
+      end
+
+      begin
+        driver.switch_to_frame(frame)
+        begin
+          yield
+        ensure
+          driver.switch_to_frame(:parent)
+        end
+      rescue Capybara::NotSupportedByDriverError
+        # Support older driver frame API for now
+        if driver.respond_to?(:within_frame)
+          driver.within_frame(frame) do
+            yield
+          end
+        else
+          raise
+        end
       end
     ensure
       scopes.pop
@@ -386,10 +429,8 @@ module Capybara
     # @raise [ArgumentError]               if both or neither arguments were provided
     #
     def switch_to_window(window = nil, options= {})
-      if window.is_a? Hash
-        options = window
-        window = nil
-      end
+      options, window = window, nil if window.is_a? Hash
+
       block_given = block_given?
       if window && block_given
         raise ArgumentError, "`switch_to_window` can take either a block or a window, not both"
@@ -404,7 +445,7 @@ module Capybara
         driver.switch_to_window(window.handle)
         window
       else
-        wait_time = Capybara::Query.new(options).wait
+        wait_time = Capybara::Queries::BaseQuery.wait(options)
         document.synchronize(wait_time, errors: [Capybara::WindowError]) do
           original_window_handle = driver.current_window_handle
           begin
@@ -501,7 +542,7 @@ module Capybara
       old_handles = driver.window_handles
       block.call
 
-      wait_time = Capybara::Query.new(options).wait
+      wait_time = Capybara::Queries::BaseQuery.wait(options)
       document.synchronize(wait_time, errors: [Capybara::WindowError]) do
         opened_handles = (driver.window_handles - old_handles)
         if opened_handles.size != 1
@@ -547,16 +588,14 @@ module Capybara
     #   @overload $0(text, options = {}, &blk)
     #     @param text [String, Regexp]  Text or regex to match against the text in the modal.  If not provided any modal is matched
     #   @overload $0(options = {}, &blk)
-    #   @option options [Numeric] :wait  How long to wait for the modal to appear after executing the block.
+    #   @option options [Numeric] :wait (Capybara.default_max_wait_time) Maximum time to wait for the modal to appear after executing the block.
     #   @return [String]  the message shown in the modal
     #   @raise [Capybara::ModalNotFound]  if modal dialog hasn't been found
     #
     def accept_alert(text_or_options=nil, options={}, &blk)
-      if text_or_options.is_a? Hash
-        options=text_or_options
-      else
-        options[:text]=text_or_options
-      end
+      text_or_options, options = nil, text_or_options if text_or_options.is_a?(Hash)
+      options[:text] ||= text_or_options unless text_or_options.nil?
+      options[:wait] ||= Capybara.default_max_wait_time
 
       driver.accept_modal(:alert, options, &blk)
     end
@@ -568,11 +607,9 @@ module Capybara
     # @macro modal_params
     #
     def accept_confirm(text_or_options=nil, options={}, &blk)
-      if text_or_options.is_a? Hash
-        options=text_or_options
-      else
-        options[:text]=text_or_options
-      end
+      text_or_options, options = nil, text_or_options if text_or_options.is_a?(Hash)
+      options[:text] ||= text_or_options unless text_or_options.nil?
+      options[:wait] ||= Capybara.default_max_wait_time
 
       driver.accept_modal(:confirm, options, &blk)
     end
@@ -584,11 +621,9 @@ module Capybara
     # @macro modal_params
     #
     def dismiss_confirm(text_or_options=nil, options={}, &blk)
-      if text_or_options.is_a? Hash
-        options=text_or_options
-      else
-        options[:text]=text_or_options
-      end
+      text_or_options, options = nil, text_or_options if text_or_options.is_a?(Hash)
+      options[:text] ||= text_or_options unless text_or_options.nil?
+      options[:wait] ||= Capybara.default_max_wait_time
 
       driver.dismiss_modal(:confirm, options, &blk)
     end
@@ -601,11 +636,9 @@ module Capybara
     # @option options [String] :with   Response to provide to the prompt
     #
     def accept_prompt(text_or_options=nil, options={}, &blk)
-      if text_or_options.is_a? Hash
-        options=text_or_options
-      else
-        options[:text]=text_or_options
-      end
+      text_or_options, options = nil, text_or_options if text_or_options.is_a?(Hash)
+      options[:text] ||= text_or_options unless text_or_options.nil?
+      options[:wait] ||= Capybara.default_max_wait_time
 
       driver.accept_modal(:prompt, options, &blk)
     end
@@ -617,11 +650,9 @@ module Capybara
     # @macro modal_params
     #
     def dismiss_prompt(text_or_options=nil, options={}, &blk)
-      if text_or_options.is_a? Hash
-        options=text_or_options
-      else
-        options[:text]=text_or_options
-      end
+      text_or_options, options = nil, text_or_options if text_or_options.is_a?(Hash)
+      options[:text] ||= text_or_options unless text_or_options.nil?
+      options[:wait] ||= Capybara.default_max_wait_time
 
       driver.dismiss_modal(:prompt, options, &blk)
     end
@@ -631,8 +662,11 @@ module Capybara
     # Save a snapshot of the page. If `Capybara.asset_host` is set it will inject `base` tag
     #   pointing to `asset_host`.
     #
-    # If invoked without arguments it will save file to `Capybara.save_and_open_page_path`
-    #   and file will be given randomly generated filename.
+    # If invoked without arguments it will save file to `Capybara.save_path`
+    #   and file will be given randomly generated filename. If invoked with a relative path
+    #   the path will be relative to `Capybara.save_path`, which is different from
+    #   the previous behavior with `Capybara.save_and_open_page_path` where the relative path was
+    #   relative to Dir.pwd
     #
     # @param [String] path  the path to where it should be saved
     # @return [String]      the path to which the file was saved
@@ -647,8 +681,11 @@ module Capybara
     #
     # Save a snapshot of the page and open it in a browser for inspection.
     #
-    # If invoked without arguments it will save file to `Capybara.save_and_open_page_path`
-    #   and file will be given randomly generated filename.
+    # If invoked without arguments it will save file to `Capybara.save_path`
+    #   and file will be given randomly generated filename. If invoked with a relative path
+    #   the path will be relative to `Capybara.save_path`, which is different from
+    #   the previous behavior with `Capybara.save_and_open_page_path` where the relative path was
+    #   relative to Dir.pwd
     #
     # @param [String] path  the path to where it should be saved
     #
@@ -661,8 +698,11 @@ module Capybara
     #
     # Save a screenshot of page.
     #
-    # If invoked without `path` argument it will save file to `Capybara.save_and_open_page_path`
-    #   and file will be given randomly generated filename.
+    # If invoked without arguments it will save file to `Capybara.save_path`
+    #   and file will be given randomly generated filename. If invoked with a relative path
+    #   the path will be relative to `Capybara.save_path`, which is different from
+    #   the previous behavior with `Capybara.save_and_open_page_path` where the relative path was
+    #   relative to Dir.pwd
     #
     # @param [String] path    the path to where it should be saved
     # @param [Hash] options   a customizable set of options
@@ -677,8 +717,11 @@ module Capybara
     #
     # Save a screenshot of the page and open it for inspection.
     #
-    # If invoked without `path` argument it will save file to `Capybara.save_and_open_page_path`
-    #   and file will be given randomly generated filename.
+    # If invoked without arguments it will save file to `Capybara.save_path`
+    #   and file will be given randomly generated filename. If invoked with a relative path
+    #   the path will be relative to `Capybara.save_path`, which is different from
+    #   the previous behavior with `Capybara.save_and_open_page_path` where the relative path was
+    #   relative to Dir.pwd
     #
     # @param [String] path    the path to where it should be saved
     # @param [Hash] options   a customizable set of options
@@ -726,15 +769,18 @@ module Capybara
     end
 
     def prepare_path(path, extension)
-      path = default_path(extension) if path.nil?
+      if Capybara.save_path || Capybara.save_and_open_page_path.nil?
+        path = File.expand_path(path || default_fn(extension), Capybara.save_path)
+      else
+        path = File.expand_path(default_fn(extension), Capybara.save_and_open_page_path) if path.nil?
+      end
       FileUtils.mkdir_p(File.dirname(path))
       path
     end
 
-    def default_path(extension)
+    def default_fn(extension)
       timestamp = Time.new.strftime("%Y%m%d%H%M%S")
       path = "capybara-#{timestamp}#{rand(10**10)}.#{extension}"
-      File.expand_path(path, Capybara.save_and_open_page_path)
     end
 
     def scopes
