@@ -1,9 +1,10 @@
+# frozen_string_literal: true
 Capybara::SpecHelper.spec '#click_link' do
   before do
     @session.visit('/with_html')
   end
 
-  it "should wait for asynchronous load", :requires => [:js] do
+  it "should wait for asynchronous load", requires: [:js] do
     @session.visit('/with_js')
     @session.click_link('Click me')
     @session.click_link('Has been clicked')
@@ -14,7 +15,7 @@ Capybara::SpecHelper.spec '#click_link' do
     expect(@session).to have_content('Another World')
   end
 
-  it "raises any errors caught inside the server", :requires => [:server] do
+  it "raises any errors caught inside the server", requires: [:server] do
     quietly { @session.visit("/error") }
     expect do
       @session.click_link('foo')
@@ -75,34 +76,34 @@ Capybara::SpecHelper.spec '#click_link' do
 
   context "with :href option given" do
     it "should find links with valid href" do
-      @session.click_link('labore', :href => '/with_simple_html')
+      @session.click_link('labore', href: '/with_simple_html')
       expect(@session).to have_content('Bar')
     end
 
     it "should raise error if link wasn't found" do
-      expect { @session.click_link('labore', :href => 'invalid_href') }.to raise_error(Capybara::ElementNotFound)
+      expect { @session.click_link('labore', href: 'invalid_href') }.to raise_error(Capybara::ElementNotFound)
     end
   end
 
   context "with a regex :href option given"  do
     it "should find a link matching an all-matching regex pattern" do
-      @session.click_link('labore', :href => /.+/)
+      @session.click_link('labore', href: /.+/)
       expect(@session).to have_content('Bar')
     end
 
     it "should find a link matching an exact regex pattern" do
-      @session.click_link('labore', :href => /\/with_simple_html/)
+      @session.click_link('labore', href: /\/with_simple_html/)
       expect(@session).to have_content('Bar')
     end
 
     it "should find a link matching a partial regex pattern" do
-      @session.click_link('labore', :href => /\/with_simple/)
+      @session.click_link('labore', href: /\/with_simple/)
       expect(@session).to have_content('Bar')
     end
 
     it "should raise an error if no link's href matched the pattern" do
-      expect { @session.click_link('labore', :href => /invalid_pattern/) }.to raise_error(Capybara::ElementNotFound)
-      expect { @session.click_link('labore', :href => /.+d+/) }.to raise_error(Capybara::ElementNotFound)
+      expect { @session.click_link('labore', href: /invalid_pattern/) }.to raise_error(Capybara::ElementNotFound)
+      expect { @session.click_link('labore', href: /.+d+/) }.to raise_error(Capybara::ElementNotFound)
     end
   end
 
@@ -134,7 +135,7 @@ Capybara::SpecHelper.spec '#click_link' do
   end
 
   it "should do nothing on anchor links" do
-    @session.fill_in("test_field", :with => 'blah')
+    @session.fill_in("test_field", with: 'blah')
     @session.click_link('Normal Anchor')
     expect(@session.find_field("test_field").value).to eq('blah')
     @session.click_link('Blank Anchor')
@@ -144,7 +145,7 @@ Capybara::SpecHelper.spec '#click_link' do
   end
 
   it "should do nothing on URL+anchor links for the same page" do
-    @session.fill_in("test_field", :with => 'blah')
+    @session.fill_in("test_field", with: 'blah')
     @session.click_link('Anchor on same page')
     expect(@session.find_field("test_field").value).to eq('blah')
   end
@@ -168,14 +169,21 @@ Capybara::SpecHelper.spec '#click_link' do
 
   context "with :exact option" do
     it "should accept partial matches when false" do
-      @session.click_link('abo', :exact => false)
+      @session.click_link('abo', exact:  false)
       expect(@session).to have_content('Bar')
     end
 
     it "should not accept partial matches when true" do
       expect do
-        @session.click_link('abo', :exact => true)
+        @session.click_link('abo', exact:  true)
       end.to raise_error(Capybara::ElementNotFound)
     end
   end
+
+  context "without locator" do
+    it "uses options" do
+      @session.click_link(href: '/foo')
+      expect(@session).to have_content('Another World')
+    end
+  end
 end
