@@ -1,4 +1,5 @@
-Capybara::SpecHelper.spec '#dismiss_confirm', :requires => [:modals] do
+# frozen_string_literal: true
+Capybara::SpecHelper.spec '#dismiss_confirm', requires: [:modals] do
   before do
     @session.visit('/with_js')
   end
@@ -32,4 +33,4 @@ Capybara::SpecHelper.spec '#dismiss_confirm', :requires => [:modals] do
     end
     expect(message).to eq('Confirm opened')
   end
-end
\ No newline at end of file
+end
