@@ -1,4 +1,5 @@
-Capybara::SpecHelper.spec '#dismiss_prompt', :requires => [:modals] do
+# frozen_string_literal: true
+Capybara::SpecHelper.spec '#dismiss_prompt', requires: [:modals] do
   before do
     @session.visit('/with_js')
   end
@@ -16,4 +17,4 @@ Capybara::SpecHelper.spec '#dismiss_prompt', :requires => [:modals] do
     end
     expect(message).to eq('Prompt opened')
   end
-end
\ No newline at end of file
+end
