@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 Capybara::SpecHelper.spec '#first' do
   before do
     @session.visit('/with_html')
@@ -5,7 +6,7 @@ Capybara::SpecHelper.spec '#first' do
 
   it "should find the first element using the given locator" do
     expect(@session.first('//h1').text).to eq('This is a test')
-    expect(@session.first("//input[@id='test_field']")[:value]).to eq('monkey')
+    expect(@session.first("//input[@id='test_field']").value).to eq('monkey')
   end
 
   it "should return nil when nothing was found" do
@@ -21,14 +22,14 @@ Capybara::SpecHelper.spec '#first' do
   context "with css selectors" do
     it "should find the first element using the given selector" do
       expect(@session.first(:css, 'h1').text).to eq('This is a test')
-      expect(@session.first(:css, "input[id='test_field']")[:value]).to eq('monkey')
+      expect(@session.first(:css, "input[id='test_field']").value).to eq('monkey')
     end
   end
 
   context "with xpath selectors" do
     it "should find the first element using the given locator" do
       expect(@session.first(:xpath, '//h1').text).to eq('This is a test')
-      expect(@session.first(:xpath, "//input[@id='test_field']")[:value]).to eq('monkey')
+      expect(@session.first(:xpath, "//input[@id='test_field']").value).to eq('monkey')
     end
   end
 
@@ -36,33 +37,33 @@ Capybara::SpecHelper.spec '#first' do
     before { Capybara.default_selector = :css }
     it "should find the first element using the given locator" do
       expect(@session.first('h1').text).to eq('This is a test')
-      expect(@session.first("input[id='test_field']")[:value]).to eq('monkey')
+      expect(@session.first("input[id='test_field']").value).to eq('monkey')
     end
   end
 
   context "with visible filter" do
     it "should only find visible nodes when true" do
-      expect(@session.first(:css, "a#invisible", :visible => true)).to be_nil
+      expect(@session.first(:css, "a#invisible", visible: true)).to be_nil
     end
 
     it "should find nodes regardless of whether they are invisible when false" do
-      expect(@session.first(:css, "a#invisible", :visible => false)).not_to be_nil
-      expect(@session.first(:css, "a#visible", :visible => false)).not_to be_nil
+      expect(@session.first(:css, "a#invisible", visible: false)).not_to be_nil
+      expect(@session.first(:css, "a#visible", visible: false)).not_to be_nil
     end
 
     it "should find nodes regardless of whether they are invisible when :all" do
-      expect(@session.first(:css, "a#invisible", :visible => :all)).not_to be_nil
-      expect(@session.first(:css, "a#visible", :visible => :all)).not_to be_nil
+      expect(@session.first(:css, "a#invisible", visible: :all)).not_to be_nil
+      expect(@session.first(:css, "a#visible", visible: :all)).not_to be_nil
     end
 
     it "should find only hidden nodes when :hidden" do
-      expect(@session.first(:css, "a#invisible", :visible => :hidden)).not_to be_nil
-      expect(@session.first(:css, "a#visible", :visible => :hidden)).to be_nil
+      expect(@session.first(:css, "a#invisible", visible: :hidden)).not_to be_nil
+      expect(@session.first(:css, "a#visible", visible: :hidden)).to be_nil
     end
 
     it "should find only visible nodes when :visible" do
-      expect(@session.first(:css, "a#invisible", :visible => :visible)).to be_nil
-      expect(@session.first(:css, "a#visible", :visible => :visible)).not_to be_nil
+      expect(@session.first(:css, "a#invisible", visible: :visible)).to be_nil
+      expect(@session.first(:css, "a#visible", visible: :visible)).not_to be_nil
     end
 
     it "should default to Capybara.ignore_hidden_elements" do
