@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 Capybara::SpecHelper.spec '#has_button?' do
   before do
     @session.visit('/form')
@@ -9,8 +10,8 @@ Capybara::SpecHelper.spec '#has_button?' do
     expect(@session).to have_button(:'crap321')
   end
 
-  it "should be true for disabled buttons if :disabled => true" do
-    expect(@session).to have_button('Disabled button', :disabled => true)
+  it "should be true for disabled buttons if disabled: true" do
+    expect(@session).to have_button('Disabled button', disabled: true)
   end
 
   it "should be false if the given button is not on the page" do
@@ -21,8 +22,16 @@ Capybara::SpecHelper.spec '#has_button?' do
     expect(@session).not_to have_button('Disabled button')
   end
 
-  it "should be false for disabled buttons if :disabled => false" do
-    expect(@session).not_to have_button('Disabled button', :disabled => false)
+  it "should be false for disabled buttons if disabled: false" do
+    expect(@session).not_to have_button('Disabled button', disabled: false)
+  end
+
+  it "should be true for disabled buttons if disabled: :all" do
+    expect(@session).to have_button('Disabled button', disabled: :all)
+  end
+
+  it "should be true for enabled buttons if disabled: :all" do
+    expect(@session).to have_button('med', disabled: :all)
   end
 end
 
@@ -36,8 +45,8 @@ Capybara::SpecHelper.spec '#has_no_button?' do
     expect(@session).not_to have_no_button('crap321')
   end
 
-  it "should be true for disabled buttons if :disabled => true" do
-    expect(@session).not_to have_no_button('Disabled button', :disabled => true)
+  it "should be true for disabled buttons if disabled: true" do
+    expect(@session).not_to have_no_button('Disabled button', disabled: true)
   end
 
   it "should be false if the given button is not on the page" do
@@ -48,7 +57,7 @@ Capybara::SpecHelper.spec '#has_no_button?' do
     expect(@session).to have_no_button('Disabled button')
   end
 
-  it "should be false for disabled buttons if :disabled => false" do
-    expect(@session).to have_no_button('Disabled button', :disabled => false)
+  it "should be false for disabled buttons if disabled: false" do
+    expect(@session).to have_no_button('Disabled button', disabled: false)
   end
 end
