@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 require 'sinatra/base'
 require 'tilt/erb'
 require 'rack'
@@ -5,7 +6,12 @@ require 'yaml'
 
 class TestApp < Sinatra::Base
   class TestAppError < StandardError; end
-
+  class TestAppOtherError < StandardError
+    def initialize(string1, msg)
+      @something = string1
+      @message = msg
+    end
+  end
   set :root, File.dirname(__FILE__)
   set :static, true
   set :raise_errors, true
@@ -124,6 +130,10 @@ class TestApp < Sinatra::Base
     raise TestAppError, "some error"
   end
 
+  get '/other_error' do
+    raise TestAppOtherError.new("something", "other error")
+  end
+
   get '/load_error' do
     raise LoadError
   end
@@ -174,5 +184,5 @@ class TestApp < Sinatra::Base
 end
 
 if __FILE__ == $0
-  Rack::Handler::WEBrick.run TestApp, :Port => 8070
+  Rack::Handler::WEBrick.run TestApp, Port: 8070
 end
