@@ -1,10 +1,11 @@
+# frozen_string_literal: true
 require 'spec_helper'
 
 module TestSessions
   RackTest = Capybara::Session.new(:rack_test, TestApp)
 end
 
-Capybara::SpecHelper.run_specs TestSessions::RackTest, "RackTest", :capybara_skip => [
+Capybara::SpecHelper.run_specs TestSessions::RackTest, "RackTest", capybara_skip: [
   :js,
   :modals,
   :screenshot,
@@ -78,6 +79,38 @@ RSpec.describe Capybara::Session do
           expect(@session.html).to include('Successfully ignored empty file field.')
         end
       end
+
+      it "should not submit an obsolete mime type" do
+        @test_jpg_file_path = File.expand_path('fixtures/capybara.csv', File.dirname(__FILE__))
+        @session.visit("/form")
+        @session.attach_file "form_document", @test_jpg_file_path
+        @session.click_button('Upload Single')
+        expect(@session).to have_content("Content-type: text/csv")
+      end
+    end
+
+    describe "#click" do
+      context "on a label" do
+        it "should toggle the associated checkbox" do
+          @session.visit("/form")
+          expect(@session).to have_unchecked_field('form_pets_cat')
+          @session.find(:label, 'Cat').click
+          expect(@session).to have_checked_field('form_pets_cat')
+          @session.find(:label, 'Cat').click
+          expect(@session).to have_unchecked_field('form_pets_cat')
+          @session.find(:label, 'McLaren').click
+          expect(@session).to have_checked_field('form_cars_mclaren', visible: :hidden)
+        end
+
+        it "should toggle the associated radio" do
+          @session.visit("/form")
+          expect(@session).to have_unchecked_field('gender_male')
+          @session.find(:label, 'Male').click
+          expect(@session).to have_checked_field('gender_male')
+          @session.find(:label, 'Female').click
+          expect(@session).to have_unchecked_field('gender_male')
+        end
+      end
     end
   end
 end
@@ -89,27 +122,27 @@ RSpec.describe Capybara::RackTest::Driver do
 
   describe ':headers option' do
     it 'should always set headers' do
-      @driver = Capybara::RackTest::Driver.new(TestApp, :headers => {'HTTP_FOO' => 'foobar'})
+      @driver = Capybara::RackTest::Driver.new(TestApp, headers: {'HTTP_FOO' => 'foobar'})
       @driver.visit('/get_header')
       expect(@driver.html).to include('foobar')
     end
 
     it 'should keep headers on link clicks' do
-      @driver = Capybara::RackTest::Driver.new(TestApp, :headers => {'HTTP_FOO' => 'foobar'})
+      @driver = Capybara::RackTest::Driver.new(TestApp, headers: {'HTTP_FOO' => 'foobar'})
       @driver.visit('/header_links')
       @driver.find_xpath('.//a').first.click
       expect(@driver.html).to include('foobar')
     end
 
     it 'should keep headers on form submit' do
-      @driver = Capybara::RackTest::Driver.new(TestApp, :headers => {'HTTP_FOO' => 'foobar'})
+      @driver = Capybara::RackTest::Driver.new(TestApp, headers: {'HTTP_FOO' => 'foobar'})
       @driver.visit('/header_links')
       @driver.find_xpath('.//input').first.click
       expect(@driver.html).to include('foobar')
     end
 
     it 'should keep headers on redirects' do
-      @driver = Capybara::RackTest::Driver.new(TestApp, :headers => {'HTTP_FOO' => 'foobar'})
+      @driver = Capybara::RackTest::Driver.new(TestApp, headers: {'HTTP_FOO' => 'foobar'})
       @driver.visit('/get_header_via_redirect')
       expect(@driver.html).to include('foobar')
     end
@@ -125,7 +158,7 @@ RSpec.describe Capybara::RackTest::Driver do
     end
 
     it "is possible to not follow redirects" do
-      @driver = Capybara::RackTest::Driver.new(TestApp, :follow_redirects => false)
+      @driver = Capybara::RackTest::Driver.new(TestApp, follow_redirects: false)
 
       @driver.visit('/redirect')
       expect(@driver.response.header['Location']).to match %r{/redirect_again$}
@@ -153,7 +186,7 @@ RSpec.describe Capybara::RackTest::Driver do
 
     context "with 21 redirect limit" do
       before do
-        @driver = Capybara::RackTest::Driver.new(TestApp, :redirect_limit => 21)
+        @driver = Capybara::RackTest::Driver.new(TestApp, redirect_limit: 21)
       end
 
       it "should follow 21 redirects" do
